@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2015-2024 MinIO, Inc.
+// Copyright (c) 2015-2025 MinIO, Inc.
 //
 // This file is part of MinIO Object Storage stack
 //
@@ -47,6 +47,27 @@ import (
 	"github.com/shirou/gopsutil/v3/process"
 )
 
+// NodeCommon - Common fields across most node-specific health structs
+type NodeCommon struct {
+	Addr  string `json:"addr"`
+	Error string `json:"error,omitempty"`
+}
+
+// GetAddr - return the address of the node
+func (n *NodeCommon) GetAddr() string {
+	return n.Addr
+}
+
+// SetAddr - set the address of the node
+func (n *NodeCommon) SetAddr(addr string) {
+	n.Addr = addr
+}
+
+// SetError - set the address of the node
+func (n *NodeCommon) SetError(err string) {
+	n.Error = err
+}
+
 const (
 	// HealthInfoVersion0 is version 0
 	HealthInfoVersion0 = ""
@@ -210,6 +231,8 @@ type Partition struct {
 	Error string `json:"error,omitempty"`
 
 	Device       string `json:"device,omitempty"`
+	Major        uint32 `json:"major"`
+	Minor        uint32 `json:"minor"`
 	Model        string `json:"model,omitempty"`
 	Revision     string `json:"revision,omitempty"`
 	Mountpoint   string `json:"mountpoint,omitempty"`
@@ -222,12 +245,26 @@ type Partition struct {
 	InodeFree    uint64 `json:"inode_free,omitempty"`
 }
 
+// NetSettings - rx/tx settings of an interface
+type NetSettings struct {
+	// hardware capacity
+	RxMaxPending uint32 `json:"rx_max_pending"`
+	TxMaxPending uint32 `json:"tx_max_pending"`
+	MaxCombined  uint32 `json:"max_combined"`
+
+	// configured limits
+	RxPending     uint32 `json:"rx_pending"`
+	TxPending     uint32 `json:"tx_pending"`
+	CombinedCount uint32 `json:"combined_count"`
+}
+
 // NetInfo contains information about a network inerface
 type NetInfo struct {
 	NodeCommon
-	Interface       string `json:"interface,omitempty"`
-	Driver          string `json:"driver,omitempty"`
-	FirmwareVersion string `json:"firmware_version,omitempty"`
+	Interface       string       `json:"interface,omitempty"`
+	Driver          string       `json:"driver,omitempty"`
+	FirmwareVersion string       `json:"firmware_version,omitempty"`
+	Settings        *NetSettings `json:"settings,omitempty"`
 }
 
 // Partitions contains all disk partitions information of a node.
@@ -241,6 +278,8 @@ type Partitions struct {
 type driveHwInfo struct {
 	Model    string
 	Revision string
+	Major    uint32
+	Minor    uint32
 }
 
 func getDriveHwInfo(partDevice string) (info driveHwInfo, err error) {
@@ -259,6 +298,16 @@ func getDriveHwInfo(partDevice string) (info driveHwInfo, err error) {
 	}
 
 	majorMinor := strings.TrimSpace(string(data))
+	mm := strings.SplitN(majorMinor, ":", 2)
+	major, err := strconv.ParseUint(mm[0], 10, 32)
+	if err == nil {
+		info.Major = uint32(major)
+	}
+	minor, err := strconv.ParseUint(mm[1], 10, 32)
+	if err == nil {
+		info.Minor = uint32(minor)
+	}
+
 	driveInfoPath := runDevDataPfx + majorMinor
 
 	var f *os.File
@@ -337,6 +386,8 @@ func GetPartitions(ctx context.Context, addr string) Partitions {
 				InodeFree:    usage.InodesFree,
 				Model:        di.Model,
 				Revision:     di.Revision,
+				Major:        di.Major,
+				Minor:        di.Minor,
 			})
 		}
 	}
@@ -997,6 +1048,7 @@ type ServerInfo struct {
 	GCStats        *GCStats          `json:"gc_stats,omitempty"`
 	MinioEnvVars   map[string]string `json:"minio_env_vars,omitempty"`
 	Edition        string            `json:"edition"`
+	License        *LicenseInfo      `json:"license,omitempty"`
 }
 
 // MinioInfo contains MinIO server and object storage information.
@@ -1016,6 +1068,7 @@ type MinioInfo struct {
 	IsKubernetes *bool            `json:"is_kubernetes"`
 	IsDocker     *bool            `json:"is_docker"`
 	Metrics      *RealtimeMetrics `json:"metrics,omitempty"`
+	TierConfigs  []TierConfig     `json:"tier_configs,omitempty"`
 }
 
 type TLSInfo struct {
@@ -1093,9 +1146,7 @@ const (
 	HealthDataTypeMinioConfig HealthDataType = "minioconfig"
 	HealthDataTypeSysCPU      HealthDataType = "syscpu"
 	HealthDataTypeSysDriveHw  HealthDataType = "sysdrivehw"
-	HealthDataTypeSysDocker   HealthDataType = "sysdocker" // is this really needed?
 	HealthDataTypeSysOsInfo   HealthDataType = "sysosinfo"
-	HealthDataTypeSysLoad     HealthDataType = "sysload" // provides very little info. Making it TBD
 	HealthDataTypeSysMem      HealthDataType = "sysmem"
 	HealthDataTypeSysNet      HealthDataType = "sysnet"
 	HealthDataTypeSysProcess  HealthDataType = "sysprocess"
@@ -1110,9 +1161,7 @@ var HealthDataTypesMap = map[string]HealthDataType{
 	"minioconfig": HealthDataTypeMinioConfig,
 	"syscpu":      HealthDataTypeSysCPU,
 	"sysdrivehw":  HealthDataTypeSysDriveHw,
-	"sysdocker":   HealthDataTypeSysDocker,
 	"sysosinfo":   HealthDataTypeSysOsInfo,
-	"sysload":     HealthDataTypeSysLoad,
 	"sysmem":      HealthDataTypeSysMem,
 	"sysnet":      HealthDataTypeSysNet,
 	"sysprocess":  HealthDataTypeSysProcess,
@@ -1127,9 +1176,7 @@ var HealthDataTypesList = []HealthDataType{
 	HealthDataTypeMinioConfig,
 	HealthDataTypeSysCPU,
 	HealthDataTypeSysDriveHw,
-	HealthDataTypeSysDocker,
 	HealthDataTypeSysOsInfo,
-	HealthDataTypeSysLoad,
 	HealthDataTypeSysMem,
 	HealthDataTypeSysNet,
 	HealthDataTypeSysProcess,
